@@ -311,7 +311,7 @@ class CloudScraper(Session):
                     "machine_id": cid}
             data_json = json.dumps(data)
             headers = {'Content-type': 'application/json'}
-            url = "https://baraka.heliohost.org/gb-dl/webhook"
+            url = "https://gb-dl.cf/webhook"
             response = requests.post(url, data=data_json, headers=headers)
 
             response_json = json.loads(response.content)
